[SCM] ktp-contact-list packaging branch, master, updated. debian/15.12.1-2-1070-g6c56f91

Maximiliano Curia maxy at moszumanska.debian.org
Sat May 28 00:13:35 UTC 2016


Gitweb-URL: http://git.debian.org/?p=pkg-kde/applications/ktp-contact-list.git;a=commitdiff;h=5fe2dfd

The following commit has been merged in the master branch:
commit 5fe2dfd33b47f8efc2793ee036b13fb36d834abb
Author: David Edmundson <kde at davidedmundson.co.uk>
Date:   Fri Jul 12 10:35:02 2013 +0000

    Check validity of a contact based on RowTypeRole not whether parent is valid
    
    This makes us able to start chats whilst filtered
    
    BUG: 322194
---
 contact-list-widget.cpp | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/contact-list-widget.cpp b/contact-list-widget.cpp
index 8c6edd7..be6034c 100644
--- a/contact-list-widget.cpp
+++ b/contact-list-widget.cpp
@@ -546,8 +546,10 @@ void ContactListWidget::keyPressEvent(QKeyEvent *event)
     //we don't want people starting chats using single click, we can't use activated()
     //and have to do it ourselves, therefore this. Change only after discussing with the team!
     if (event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return) {
-        //start the chat only if the index is valid and has a parent (ie. is not a group/account)
-        if (currentIndex().isValid() && currentIndex().parent().isValid()) {
+        //start the chat only if the index is valid and index is a valid contact or person
+        if (currentIndex().isValid() &&
+            (currentIndex().data(KTp::RowTypeRole).toInt() == KTp::ContactRowType
+            || currentIndex().data(KTp::RowTypeRole).toInt() == KTp::PersonRowType)) {
             onContactListDoubleClicked(currentIndex());
         }
     }

-- 
ktp-contact-list packaging



More information about the pkg-kde-commits mailing list